var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import * as filterSelectors from '../store/selectors';
import FormatSize from '@material-ui/icons/FormatSize';
import IconButton from '@material-ui/core/IconButton';
import React, { Component } from 'react';
import Switch from '@material-ui/core/Switch';
import TextField from '@material-ui/core/TextField';
import Toolbar from '@material-ui/core/Toolbar';
import Tooltip from '@material-ui/core/Tooltip';
import { DatePicker } from 'material-ui-pickers';
import Checkbox from '@material-ui/core/Checkbox';
import FormGroup from '@material-ui/core/FormGroup';
import FormControlLabel from '@material-ui/core/FormControlLabel';
import FormControl from '@material-ui/core/FormControl';
import FormLabel from '@material-ui/core/FormLabel';

export var SearchField = function SearchField(_ref) {
  var theme = _ref.theme,
      queryIndex = _ref.queryIndex,
      currentField = _ref.currentField,
      query = _ref.query,
      formatMessage = _ref.formatMessage,
      fields = _ref.fields,
      handleQueryChange = _ref.handleQueryChange,
      DateTimeFormat = _ref.DateTimeFormat,
      locale = _ref.locale,
      okLabel = _ref.okLabel,
      cancelLabel = _ref.cancelLabel;

  var _filterSelectors$sele = filterSelectors.selectQueryProps(query),
      value = _filterSelectors$sele.value,
      isCaseSensitive = _filterSelectors$sele.isCaseSensitive;

  if (queryIndex == null || currentField == null || query == null || handleQueryChange == null || fields == null) {
    return React.createElement('div', null);
  }

  var fieldType = '';
  var fieldLabel = '';
  var fieldData = [];

  fields.map(function (field) {
    if (field.name === currentField.value) {
      fieldType = field.type;
      fieldLabel = field.label;
      fieldData = field.data;
    }
    return field;
  });

  if (fieldType === 'enum') {
    return React.createElement(
      Toolbar,
      null,
      React.createElement(EnumList, { list: fieldData, handleQueryChange: handleQueryChange, queryIndex: queryIndex })
    );
  }

  if (fieldType === 'date') {
    return React.createElement(
      Toolbar,
      null,
      React.createElement(DatePicker, {
        keyboard: true,
        label: formatMessage ? formatMessage({ id: 'enter_query_text' }) : '',
        format: 'DD/MM/YYYY',
        placeholder: '10/10/2018',
        mask: function mask(value) {
          return value ? [/\d/, /\d/, '/', /\d/, /\d/, '/', /\d/, /\d/, /\d/, /\d/] : [];
        },
        value: value,
        onChange: function onChange(val) {
          handleQueryChange(queryIndex, 'value', val.format());
        },
        disableOpenOnEnter: true,
        animateYearScrolling: false
      })
    );
  }

  if (fieldType === 'bool') {
    return React.createElement(
      Toolbar,
      null,
      React.createElement(Switch, {
        label: fieldLabel,
        onChange: function onChange(e, val) {
          handleQueryChange(queryIndex, 'value', val);
        },
        value: value
      })
    );
  } else {
    //string

    return React.createElement(
      Toolbar,
      null,
      React.createElement(TextField, {
        fullWidth: true,
        name: 'value',
        onChange: function onChange(e, val) {
          handleQueryChange(queryIndex, 'value', e.target.value);
        },
        value: value ? value : '',
        placeholder: formatMessage ? formatMessage({ id: 'enter_query_text' }) : ''
      }),
      React.createElement(
        Tooltip,
        {
          id: 'tooltip-bottom-start',
          title: formatMessage ? formatMessage({ id: isCaseSensitive ? 'disable_case_sensitivity' : 'enable_case_sensitivity' }) : '',
          placement: 'bottom-end'
        },
        React.createElement(
          IconButton,
          {
            onClick: function onClick() {
              handleQueryChange(queryIndex, 'isCaseSensitive', !isCaseSensitive);
            },
            color: isCaseSensitive ? 'primary' : undefined
          },
          React.createElement(FormatSize, null)
        )
      )
    );
  }
};

var EnumList = function (_Component) {
  _inherits(EnumList, _Component);

  function EnumList(props) {
    _classCallCheck(this, EnumList);

    // Don't call this.setState() here!
    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.state = {};
    _this.handleChange = _this.handleChange.bind(_this);
    _this.capitalize = _this.capitalize.bind(_this);
    return _this;
  }

  EnumList.prototype.handleChange = function handleChange(event) {
    var _extends2, _setState;

    var _props = this.props,
        list = _props.list,
        handleQueryChange = _props.handleQueryChange,
        queryIndex = _props.queryIndex;


    var values = _extends({}, this.state, (_extends2 = {}, _extends2[event.target.value] = event.target.checked, _extends2));
    var vals = [];
    Object.keys(list).map(function (item) {
      var name = list[item];
      if (values[name]) {
        vals.push(name.toUpperCase());
      }
    });
    this.setState((_setState = {}, _setState[event.target.value] = event.target.checked, _setState));
    handleQueryChange(queryIndex, 'value', vals);
  };

  EnumList.prototype.capitalize = function capitalize(str) {
    return str.charAt(0).toUpperCase() + str.slice(1);
  };

  EnumList.prototype.componentWillMount = function componentWillMount() {
    var _this2 = this;

    var _props2 = this.props,
        list = _props2.list,
        handleQueryChange = _props2.handleQueryChange;

    var state = this.state;
    Object.keys(list).map(function (item, index) {
      var _extends3;

      var name = list[item];
      _this2.setState(_extends({}, state, (_extends3 = {}, _extends3[name] = true, _extends3)));
    });
  };

  EnumList.prototype.render = function render() {
    var _this3 = this;

    var list = this.props.list;


    return React.createElement(
      FormControl,
      { component: 'fieldset' },
      React.createElement(
        FormGroup,
        { 'aria-label': 'position', name: 'position', onChange: this.handleChange },
        Object.keys(list).map(function (item) {
          var name = list[item];
          return React.createElement(FormControlLabel, {
            key: name,
            value: name,
            control: React.createElement(Checkbox, { color: 'primary', checked: _this3.state[name] }),
            label: _this3.capitalize(name),
            labelPlacement: 'end'
          });
        })
      )
    );
  };

  return EnumList;
}(Component);